@@ -18,7 +18,6 @@
 #include <stdint.h>
 #include <string.h>
 
-#include "batadv_packet.h"
 #include "batman_adv.h"
 #include "bat-hosts.h"
 #include "debug.h"
@@ -35,14 +34,16 @@ static const int originators_mandatory[] = {
 
 static int originators_callback(struct nl_msg *msg, void *arg)
 {
-	unsigned throughput_mbits, throughput_kbits;
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
-	int last_seen_msecs, last_seen_secs;
+	unsigned int throughput_mbits;
+	unsigned int throughput_kbits;
 	struct print_opts *opts = arg;
 	char ifname_buf[IF_NAMESIZE];
 	struct bat_host *bat_host;
 	struct genlmsghdr *ghdr;
+	int last_seen_msecs;
+	int last_seen_secs;
 	uint32_t ifindex;
 	float last_seen;
 	uint8_t *neigh;
@@ -68,7 +69,7 @@ static int originators_callback(struct nl_msg *msg, void *arg)
 	}
 
 	if (missing_mandatory_attrs(attrs, originators_mandatory,
-				       ARRAY_SIZE(originators_mandatory))) {
+				    ARRAY_SIZE(originators_mandatory))) {
 		fputs("Missing attributes from kernel\n", stderr);
 		exit(1);
 	}
